@@ -27,6 +27,7 @@
 
 #include "generator.h"
 
+class QElapsedTimer;
 class QTimer;
 
 namespace KScreen
@@ -79,6 +80,7 @@ class Q_DECL_EXPORT KScreenDaemon : public KDEDModule
         QTimer* m_buttonTimer;
         QTimer* m_saveTimer;
         QTimer* m_lidClosedTimer;
+        QScopedPointer<QElapsedTimer> m_changeBlockTimer;
 };
 
 #endif /*KSCREN_DAEMON_H*/
